@@ -1,7 +1,7 @@
 from ._error import NotInstalled
 from ._grid import grid, random_grid
 from ._base import memlist, memfile, memfunc
-from ._common import capture_time
+from ._util import time_taken
 
 try:
     from memo._http import memweb
@@ -14,7 +14,7 @@ except ModuleNotFoundError:
     memwandb = NotInstalled("memwandb", "wandb")
 
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __all__ = [
     "grid",
     "random_grid",
@@ -23,5 +23,5 @@ __all__ = [
     "memfunc",
     "memweb",
     "memwandb",
-    "capture_time"
+    "time_taken",
 ]
